@@ -10,6 +10,8 @@ from autots.datasets._base import (
     load_weekly,
     load_weekdays,
     load_zeroes,
+    load_linear,
+    load_sine,
 )
 
 __all__ = [
@@ -21,4 +23,6 @@ __all__ = [
     'load_weekdays',
     'load_live_daily',
     'load_zeroes',
+    'load_linear',
+    'load_sine',
 ]
